@@ -179,8 +179,9 @@ class PARAMETROS:
             # avalidando os DataTypes para o ResultSet
             for row in rs:
                 if row["flg_encrypt"] == "S":
-                    token_string = self.VARIAVEL_get(["GERAL_TOKEN_BASE"])[0]
-                    row["val_parametro"] = utl.CRYPTOGRAPHY(word=row["val_parametro"], token=token_string)
+                    #token_string = self.VARIAVEL_get(["GERAL_TOKEN_BASE"])[0]
+                    #row["val_parametro"] = utl.CRYPTOGRAPHY(word=row["val_parametro"], token=token_string)
+                    row["val_parametro"] = utl.base64_decrypt(word=row["val_parametro"])
                 if row["des_datatype"] == "DATETIME":
                     row["val_parametro"] = dt.datetime.strptime(utl.iif(row["val_parametro"] is None, "", row["val_parametro"]), "%Y-%m-%d %H:%M:%S")
                 elif row["des_datatype"] == "DATE":
